California Secretary of State - CalAccess - Campaign Finance

Advanced Search
| Candidates & Elected Officials
Propositions & Ballot Measures
Committees, Parties, Major Donors & Slate Mailers
Daily/Late/ Special Filings
| Campaign Finance: PROPOSITION 001A - STATE BUDGET. CHANGES CALIFORNIA BUDGET PROCESS. LIMITS STATE SPENDING. INCREASES "RAINY DAY " BUDGET STABILIZATION FUND. View Information: General Information Late Independent Expenditures Affecting This Measure
How much money is being raised and spent to pass or defeat California propositions and ballot measures, and what are the sources of the money? Check here to follow the money trail.
Committees formed to support or oppose the ballot measure.
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1317763 | NO ON 1A, A COALITION OF TEACHERS, FACULTY, NURSES, HEALTH CARE PROVIDERS, SENIORS AND PUBLIC EMPLOYEES FIGHTING FOR REAL BUDGET REFORM | OPPOSE
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1316527 | NAPA COUNTY CITIZENS AGAINST PROP 1A | OPPOSE
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1315905 | BUDGET REFORM NOW, A COALITION OF TAXPAYERS, BUSINESS, LABOR, EDUCATORS, PUBLIC SAFETY, SENIORS, GOVERNOR SCHWARZENEGGER'S CALIFORNIA DREAM TEAM, A BALLOT MEASURE COMM"..." | SUPPORT
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
922117 | NO NEW TAXES, A PROJECT OF THE HOWARD JARVIS TAXPAYERS ASSOCIATION | OPPOSE
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1317838 | CALIFORNIANS AGAINST NEW TAXES, NO ON 1A COMMITTEE | OPPOSE
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1317867 | AMERICAN FEDERATION OF STATE, COUNTY & LOCAL MUNICIPAL EMPLOYEES LOCAL 2620 ISSUES COMMITEE, YES ON 1A, 1B, 1C, 1D, 1E AND 1F | SUPPORT
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1317887 | STOP TAXING US: NO ON 1A-F | OPPOSE
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1316255 | YES ON 1A AND 1B, REPAY AND PROTECT OUR SCHOOLS: A COALITION OF CALIFORNIA TEACHERS ASSOCIATION ISSUES PAC AND NATIONAL EDUCATION ASSOCIATION COMMITTEES. | SUPPORT
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
881029 | CALIFORNIA FACULTY ASSOCIATION POLITICAL ISSUES COMMITTEE | OPPOSE
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1261406 | SCHWARZENEGGER'S CALIFORNIA DREAM TEAM, A BALLOT MEASURE COMMITTEE, GOVERNOR | SUPPORT
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1318023 | SAVE SENIOR SERVICES, CALIFORNIA ALLIANCE FOR RETIRED AMERICANS - NO ON 1A | OPPOSE